@@ -1,10 +1,10 @@
 from .base_consumer import BaseConsumer
 from .config import ConsumerConfig, RedispatcherConfig
-from .consumer_pool import ConsumerPool
-from .models import MessageContainer
 from .monitor import monitor_cli
+from .redispatcher import Redispatcher
+from .types import MessageContainer
 
-__version__ = "0.1.4"
+__version__ = "0.2.0"
 
 __all__ = [
     # Consumer
@@ -13,7 +13,7 @@ __all__ = [
     "ConsumerConfig",
     "RedispatcherConfig",
     # Pool
-    "ConsumerPool",
+    "Redispatcher",
     # Arbitrary Models
     "MessageContainer",
     # Scripts
